<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "California";
    var qsoPartyUrl = "http://www.cqp.org/Rules.html";
    var overlayUrl = "http://www.no5w.com/OverlayCaliforniaRev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Alameda", "alam");
  countySelection.options[1] = new Option("Alpine", "alpi");
  countySelection.options[2] = new Option("Amador", "amad");
  countySelection.options[3] = new Option("Butte", "butt");
  countySelection.options[4] = new Option("Calaveras", "cala");
  countySelection.options[5] = new Option("Colusa", "colu");
  countySelection.options[6] = new Option("ContraCosta", "ccos");
  countySelection.options[7] = new Option("DelNorte", "deln");
  countySelection.options[8] = new Option("ElDorado", "eldo");
  countySelection.options[9] = new Option("Fresno", "fres");
  countySelection.options[10] = new Option("Glenn", "glen");
  countySelection.options[11] = new Option("Humboldt", "humb");
  countySelection.options[12] = new Option("Imperial", "impe");
  countySelection.options[13] = new Option("Inyo", "inyo");
  countySelection.options[14] = new Option("Kern", "kern");
  countySelection.options[15] = new Option("Kings", "king");
  countySelection.options[16] = new Option("Lake", "lake");
  countySelection.options[17] = new Option("Lassen", "lass");
  countySelection.options[18] = new Option("LosAngeles", "lang");
  countySelection.options[19] = new Option("Madera", "made");
  countySelection.options[20] = new Option("Marin", "marn");
  countySelection.options[21] = new Option("Mariposa", "marp");
  countySelection.options[22] = new Option("Mendocino", "mend");
  countySelection.options[23] = new Option("Merced", "merc");
  countySelection.options[24] = new Option("Modoc", "modo");
  countySelection.options[25] = new Option("Mono", "mono");
  countySelection.options[26] = new Option("Monterey", "mont");
  countySelection.options[27] = new Option("Napa", "napa");
  countySelection.options[28] = new Option("Nevada", "neva");
  countySelection.options[29] = new Option("Orange", "oran");
  countySelection.options[30] = new Option("Placer", "plac");
  countySelection.options[31] = new Option("Plumas", "plum");
  countySelection.options[32] = new Option("Riverside", "rive");
  countySelection.options[33] = new Option("Sacramento", "sacr");
  countySelection.options[34] = new Option("SanBenito", "sben");
  countySelection.options[35] = new Option("SanBernardino", "sber");
  countySelection.options[36] = new Option("SanDiego", "sdie");
  countySelection.options[37] = new Option("SanFrancisco", "sfra");
  countySelection.options[38] = new Option("SanJoaquin", "sjoa");
  countySelection.options[39] = new Option("SanLuisObispo", "slui");
  countySelection.options[40] = new Option("SanMateo", "smat");
  countySelection.options[41] = new Option("SantaBarbara", "sbar");
  countySelection.options[42] = new Option("SantaClara", "scla");
  countySelection.options[43] = new Option("SantaCruz", "scru");
  countySelection.options[44] = new Option("Shasta", "shas");
  countySelection.options[45] = new Option("Sierra", "sier");
  countySelection.options[46] = new Option("Siskiyou", "sisk");
  countySelection.options[47] = new Option("Solano", "sola");
  countySelection.options[48] = new Option("Sonoma", "sono");
  countySelection.options[49] = new Option("Stanislaus", "stan");
  countySelection.options[50] = new Option("Sutter", "sutt");
  countySelection.options[51] = new Option("Tehama", "teha");
  countySelection.options[52] = new Option("Trinity", "trin");
  countySelection.options[53] = new Option("Tulare", "tula");
  countySelection.options[54] = new Option("Tuolumne", "tuol");
  countySelection.options[55] = new Option("Ventura", "vent");
  countySelection.options[56] = new Option("Yolo", "yolo");
  countySelection.options[57] = new Option("Yuba", "yuba");
  addMarker(37.67980000, -121.92200000, "Alameda", "alam");
  addMarker(38.63010000, -119.80800000, "Alpine", "alpi");
  addMarker(38.46350000, -120.55000000, "Amador", "amad");
  addMarker(39.72380000, -121.57300000, "Butte", "butt");
  addMarker(38.17060000, -120.50800000, "Calaveras", "cala");
  addMarker(39.16930000, -122.29000000, "Colusa", "colu");
  addMarker(37.90920000, -121.98800000, "ContraCosta", "ccos");
  addMarker(41.69090000, -123.97900000, "DelNorte", "deln");
  addMarker(38.78500000, -120.50900000, "ElDorado", "eldo");
  addMarker(36.74630000, -119.64000000, "Fresno", "fres");
  addMarker(39.59180000, -122.39700000, "Glenn", "glen");
  addMarker(40.73350000, -123.94400000, "Humboldt", "humb");
  addMarker(33.02620000, -115.28500000, "Imperial", "impe");
  addMarker(36.62590000, -117.21900000, "Inyo", "inyo");
  addMarker(35.29450000, -118.90500000, "Kern", "kern");
  addMarker(36.13880000, -119.89500000, "Kings", "king");
  addMarker(39.12440000, -122.71700000, "Lake", "lake");
  addMarker(40.44610000, -120.66400000, "Lassen", "lass");
  addMarker(33.78660000, -118.29900000, "LosAngeles", "lang");
  addMarker(37.27050000, -119.78400000, "Madera", "made");
  addMarker(38.06810000, -122.74100000, "Marin", "marn");
  addMarker(37.54360000, -119.85100000, "Mariposa", "marp");
  addMarker(39.38030000, -123.47800000, "Mendocino", "mend");
  addMarker(37.18690000, -120.65000000, "Merced", "merc");
  addMarker(41.59060000, -120.72800000, "Modoc", "modo");
  addMarker(38.08800000, -118.74200000, "Mono", "mono");
  addMarker(36.35430000, -121.13300000, "Monterey", "mont");
  addMarker(38.50960000, -122.35400000, "Napa", "napa");
  addMarker(39.26600000, -120.64600000, "Nevada", "neva");
  addMarker(33.64080000, -117.76900000, "Orange", "oran");
  addMarker(39.01400000, -120.74400000, "Placer", "plac");
  addMarker(40.02350000, -120.79900000, "Plumas", "plum");
  addMarker(33.75290000, -116.05600000, "Riverside", "rive");
  addMarker(38.37740000, -121.44400000, "Sacramento", "sacr");
  addMarker(36.59290000, -121.12000000, "SanBenito", "sben");
  addMarker(34.84010000, -115.96700000, "SanBernardino", "sber");
  addMarker(33.01690000, -116.84600000, "SanDiego", "sdie");
  addMarker(37.78490000, -122.72800000, "SanFrancisco", "sfra");
  addMarker(37.89060000, -121.25300000, "SanJoaquin", "sjoa");
  addMarker(35.34710000, -120.45500000, "SanLuisObispo", "slui");
  addMarker(37.38120000, -122.33500000, "SanMateo", "smat");
  addMarker(34.26280000, -119.84900000, "SantaBarbara", "sbar");
  addMarker(37.18880000, -121.70500000, "SantaClara", "scla");
  addMarker(37.05290000, -121.94900000, "SantaCruz", "scru");
  addMarker(40.73510000, -122.19400000, "Shasta", "shas");
  addMarker(39.58470000, -120.52900000, "Sierra", "sier");
  addMarker(41.50090000, -122.58300000, "Siskiyou", "sisk");
  addMarker(38.28540000, -122.00000000, "Solano", "sola");
  addMarker(38.46310000, -122.99000000, "Sonoma", "sono");
  addMarker(37.60610000, -120.93700000, "Stanislaus", "stan");
  addMarker(39.02040000, -121.68100000, "Sutter", "sutt");
  addMarker(40.12530000, -122.20400000, "Tehama", "teha");
  addMarker(40.67250000, -123.03500000, "Trinity", "trin");
  addMarker(36.26700000, -118.77700000, "Tulare", "tula");
  addMarker(38.03340000, -119.92500000, "Tuolumne", "tuol");
  addMarker(34.03240000, -119.13400000, "Ventura", "vent");
  addMarker(38.61940000, -121.96200000, "Yolo", "yolo");
  addMarker(39.27890000, -121.32300000, "Yuba", "yuba");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

